Gradient Boosting Machine-Locfit: A GBM framework using local regresssion via Locfit.
For information on Locfit see: http://ect.bell-labs.com/sl/project/locfit/index.html

This package offers predictions for bulk and shear moduli given material descriptors and training data.

### Citing
de Jong M, Chen W, Notestine R, Persson K, Ceder G, Jain A, Asta M, Gamst A. "A Statistical Learning Framework for Materials Science: Application to Elastic Moduli of k-nary Inorganic Polycrystalline Compounds." *Scientific Reports* **6**: 34256 (2016) | [doi:10.1038/srep34256](http://dx.doi.org/10.1038/srep34256).
